==> huawei_scan-1.3.0%2B300.tar.gz: example/lib/screens/MultiProcessorScreen.dart <==
/*
    Copyright 2020-2021. Huawei Technologies Co., Ltd. All rights reserved.

    Licensed under the Apache License, Version 2.0 (the "License")
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        https://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'dart:typed_data';

import 'package:huawei_scan/HmsScanLibrary.dart';

import 'package:huawei_scan_example/widgets/CustomButton.dart';
import 'package:huawei_scan_example/widgets/ResponseWidget.dart';

class MultiProcessorScreen extends StatefulWidget {
  @override
  _MultiProcessorScreenState createState() => _MultiProcessorScreenState();
}

class _MultiProcessorScreenState extends State<MultiProcessorScreen> {
  ScanResponseList scanList;

  decodeMultiSync() async {
    Uint8List data = (await rootBundle.load('assets/multipleBarcode2.png'))
        .buffer
        .asUint8List();

    try {
      ScanResponseList response = await HmsMultiProcessor.decodeMultiSync(
          DecodeRequest(data: data, scanType: HmsScanTypes.AllScanType));

      setState(() {
        scanList = response;
      });
    } on PlatformException catch (err) {
      if (err.code == HmsScanErrors.decodeMultiSyncCouldntFind.errorCode) {
        debugPrint(HmsScanErrors.decodeMultiSyncCouldntFind.errorMessage);
      }
    }
  }

  decodeMultiAsync() async {
    Uint8List data = (await rootBundle.load('assets/multipleBarcode2.png'))
        .buffer
        .asUint8List();

    try {
      ScanResponseList response = await HmsMultiProcessor.decodeMultiAsync(
          DecodeRequest(data: data, scanType: HmsScanTypes.AllScanType));
      setState(() {
        scanList = response;
      });
    } on PlatformException catch (err) {
      if (err.code == HmsScanErrors.decodeMultiAsyncCouldntFind.errorCode) {
        debugPrint(HmsScanErrors.decodeMultiAsyncCouldntFind.errorMessage);
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('Decode with Multi Processor Screen'),
      ),
      body: SingleChildScrollView(
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.stretch,
          mainAxisSize: MainAxisSize.min,
          children: [
            Row(
              mainAxisSize: MainAxisSize.max,
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                Container(
                  width: MediaQuery.of(context).size.width,
                  child: Image.asset("assets/multipleBarcode2.png"),
                )
              ],
            ),
            CustomButton(
              text: "Multi Processor Sync Mode",
              onPressed: () {
                decodeMultiSync();
              },
            ),
            CustomButton(
              text: "Multi Processor Async Mode",
              onPressed: () {
                decodeMultiAsync();
              },
            ),
            scanList != null
                ? ListView.builder(
                    shrinkWrap: true,
                    physics: NeverScrollableScrollPhysics(),
                    itemCount: scanList.scanResponseList.length,
                    itemBuilder: (BuildContext ctxt, int index) {
                      return ResponseWidget(
                        isMulti: true,
                        codeFormat: scanList.scanResponseList[index].scanType,
                        result: scanList.scanResponseList[index].originalValue,
                        resultType:
                            scanList.scanResponseList[index].scanTypeForm,
                      );
                    })
                : SizedBox.shrink(),
          ],
        ),
      ),
    );
  }
}

==> huawei_scan-2.1.0%2B300.tar.gz: example/lib/screens/MultiProcessorScreen.dart <==
/*
    Copyright 2020-2021. Huawei Technologies Co., Ltd. All rights reserved.

    Licensed under the Apache License, Version 2.0 (the "License")
    you may not use this file except in compliance with the License.
    You may obtain a copy of the License at

        https://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.
*/

import 'package:flutter/material.dart';
import 'package:flutter/services.dart';
import 'dart:typed_data';

import 'package:huawei_scan/HmsScanLibrary.dart';

import 'package:huawei_scan_example/widgets/CustomButton.dart';
import 'package:huawei_scan_example/widgets/ResponseWidget.dart';

class MultiProcessorScreen extends StatefulWidget {
  @override
  _MultiProcessorScreenState createState() => _MultiProcessorScreenState();
}

class _MultiProcessorScreenState extends State<MultiProcessorScreen> {
  ScanResponseList? scanList;

  decodeMultiSync() async {
    Uint8List data = (await rootBundle.load('assets/multipleBarcode2.png'))
        .buffer
        .asUint8List();

    try {
      ScanResponseList response = await HmsMultiProcessor.decodeMultiSync(
          DecodeRequest(data: data, scanType: HmsScanTypes.AllScanType));

      setState(() {
        scanList = response;
      });
    } on PlatformException catch (err) {
      if (err.code == HmsScanErrors.decodeMultiSyncCouldntFind.errorCode) {
        debugPrint(HmsScanErrors.decodeMultiSyncCouldntFind.errorMessage);
      }
    }
  }

  decodeMultiAsync() async {
    Uint8List data = (await rootBundle.load('assets/multipleBarcode2.png'))
        .buffer
        .asUint8List();

    try {
      ScanResponseList response = await HmsMultiProcessor.decodeMultiAsync(
          DecodeRequest(data: data, scanType: HmsScanTypes.AllScanType));
      setState(() {
        scanList = response;
      });
    } on PlatformException catch (err) {
      if (err.code == HmsScanErrors.decodeMultiAsyncCouldntFind.errorCode) {
        debugPrint(HmsScanErrors.decodeMultiAsyncCouldntFind.errorMessage);
      }
    }
  }

  @override
  Widget build(BuildContext context) {
    return Scaffold(
      appBar: AppBar(
        title: const Text('Decode with Multi Processor Screen'),
      ),
      body: SingleChildScrollView(
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.stretch,
          mainAxisSize: MainAxisSize.min,
          children: [
            Row(
              mainAxisSize: MainAxisSize.max,
              mainAxisAlignment: MainAxisAlignment.center,
              children: [
                Container(
                  width: MediaQuery.of(context).size.width,
                  child: Image.asset("assets/multipleBarcode2.png"),
                )
              ],
            ),
            CustomButton(
              text: "Multi Processor Sync Mode",
              onPressed: () {
                decodeMultiSync();
              },
            ),
            CustomButton(
              text: "Multi Processor Async Mode",
              onPressed: () {
                decodeMultiAsync();
              },
            ),
            scanList != null && scanList!.scanResponseList != null
                ? ListView.builder(
                    shrinkWrap: true,
                    physics: NeverScrollableScrollPhysics(),
                    itemCount: scanList!.scanResponseList!.length,
                    itemBuilder: (BuildContext ctxt, int index) {
                      return ResponseWidget(
                        isMulti: true,
                        codeFormat:
                            scanList?.scanResponseList?[index]?.scanType,
                        result:
                            scanList?.scanResponseList?[index]?.originalValue,
                        resultType:
                            scanList?.scanResponseList?[index]?.scanTypeForm,
                      );
                    })
                : SizedBox.shrink(),
          ],
        ),
      ),
    );
  }
}
